;+
; NAME:
;       HXT_FANS
; PURPOSE:
;       extract fan-beam elements from HXT and display
; OUTPUTS:
;       fan_data = channel rates
;       fan_index = index
; CALLING SEQUENCE:
;       hxt_fans,index,data,fan_index,fan_data,plot=plot (from HDA read)
; KEYWORDS
;       /plot makes plots
;	/nonorm extracts raw rates (counts/subcollimator/sec)
;       channel
;       photons
;       sums give (4,4,n) where the 2nd variable represents position
;         angle, the sums of all phases (divided by 4). 
; OUTPUTS:
;       fan_data(4,16,n) where n is the flare mode high-rate data array;
;         order among the 16 entries is phase, then PA 
;       fan_index
; HISTORY:
;       25 Sep. 1992, written by HSH
;       24 Oct, nonorm 
;       23 May 1996, added channel for plot ID and re-ordered arguments
;       27 May 1996, replaced /nonorm with /photons, ie standardized
;              on cts/sc/sec; added sums = sums to get four summed 
;              outputs (for each position angle)
;       30 apr 2001, debugged SUMS (HSH)
;-
pro hxt_fans,index,data,fan_index,fan_data,plot=plot,channel=channel,$
  photons=photons, sums=sums, qdebug=qdebug
if n_elements(channel) eq 0 then channel = 0
ff = [[0,1,5,4],[12,13,9,8],[52,53,49,48],[56,57,61,60]]
pa = [[90,90,90,90],[0,0,0,0],[135,135,135,135],[45,45,45,45]]
ph = [[1,2,3,4],[1,2,3,4],[1,2,3,4],[1,2,3,4]]
edges = [13.9,22.7,32.7,52.7,92.8]
widths = edges(1:4) - edges(0:3)
centers = (edges(1:4) + edges(0:3))/2.
area = 64 * .25 * 6.25
ss = where(gt_dp_mode(index) eq 9 and gt_dp_rate(index) eq 4,nmax)
if nmax eq -1 then bail
fan_index = index(ss)
fans = rebin(hxt_decomp(data(*,ff,*,ss)),4,16,1,nmax,/samp)
                                       ;
fans = reform(fans)*2.                 ;    in units of cts/sc/sec
                                       ;
fan_data = fans
if(keyword_set(photons)) then $ 
for i = 0,3 do fans(i,*,*) = fans(i,*,*)/area/widths(i)
maxim = max(fans)
if (keyword_set(plot)) then begin
  !p.multi = [0,4,4]
  for i = 0,15 do utplot,fan_index,fans(channel,i,*),$
    tit='PA = '+strtrim(pa(i),1)+', phase '+$
    strtrim(ph(i),1),charsize=1.5,xtit='',yr=[0,maxim]
  !p.multi = 0
endif
sums = fltarr(4,4,nmax)
for k = 0, nmax-1 do begin
  for j = 0,3 do begin
    for i = 0,3 do begin
      sums(j,i,k) = total(fans(j,4*i+indgen(4),k),2)/4 
    endfor
  endfor
endfor
clear_utplot
clearplot
!p.multi = 0
bail:
if nmax eq -1 then print, 'No flare data here, bub'
if keyword_set(qdebug) then stop
end

